==> postgrest-6.0.0-44-x86_64.pkg.tar.xz: usr/share/haskell/register/postgrest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgrest
version: 6.0.0
id: postgrest-6.0.0-K952DSeDd6UFob6KpHdNi2
key: postgrest-6.0.0-K952DSeDd6UFob6KpHdNi2
license: MIT
maintainer: Steve Chávez <stevechavezast@gmail.com>
author: Joe Nelson, Adam Baker
homepage: https://postgrest.org
synopsis: REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for the tables and views, supporting all HTTP verbs that security
    permits.
category: Executable, PostgreSQL, Network APIs
abi: 3c9a664651509f786cb2a867093702b8
exposed: True
exposed-modules:
    PostgREST.ApiRequest PostgREST.App PostgREST.Auth PostgREST.Config
    PostgREST.DbRequestBuilder PostgREST.DbStructure PostgREST.Error
    PostgREST.Middleware PostgREST.OpenAPI PostgREST.Parsers
    PostgREST.QueryBuilder PostgREST.RangeQuery PostgREST.Types
hidden-modules: Paths_postgrest
import-dirs: /usr/lib/ghc-8.6.5/site-local/postgrest-6.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/postgrest-6.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/postgrest-6.0.0
hs-libraries: HSpostgrest-6.0.0-K952DSeDd6UFob6KpHdNi2
depends:
    HTTP-4000.3.14-7dCcY5Fd9ii5gqpDuRqlcJ
    Ranged-sets-0.4.0-2PchdoGuiayH3uspliUnwe
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW
    ansi-wl-pprint-0.6.9-37GARRLGI1c3EMKKxSVRl0 base-4.12.0.0
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    cassava-0.5.2.0-8Du2Yyr9GN14usDmmst0N0
    configurator-pg-0.1.0.3-7yaDMBEO8dV27xGcIAgKV5 containers-0.6.0.1
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    contravariant-extras-0.3.4-35VdvcJZeo7BMor95g7S78
    cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx
    either-5.0.1.1-2VKwsQfBk468OCmiRorzav
    gitrev-1.3.1-28bODUJmuLsJT3tLybQkQz
    hasql-1.4-7UdsAT0XqKl8rnVjWqDp7E
    hasql-pool-0.5.1-JvbhYWY6VPKHYH98eM8XYs
    hasql-transaction-0.7.2-COyZoM2tM7uJcocXoFGxHx
    heredoc-0.2.0.0-5CGfN4QKKxO6xWz8UL0AnE
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    insert-ordered-containers-0.2.2-A9ItFeaHZCIFpAqu8gtwcA
    interpolatedstring-perl6-1.0.2-7EaGRMXyefqEWcJSOmxCL2
    jose-0.7.0.0-1Vv9NAj5S2M7Cyy8O93GLu
    lens-4.17.1-LAhRbmSla4gFq61XVUqFfx
    lens-aeson-1.0.2-7uEc2tfwgdmLKepkk8yb4k
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5
    parsec-3.1.13.0 protolude-0.2.4-2qoMYhlKlNqBovj30f65Uv
    regex-tdfa-1.2.3.2-1zrqdepzFAcLwdkKMIY7hi
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    swagger2-2.3.1.1-5L95mlw35Yd5PekgNW1mLs text-1.2.3.1 time-1.8.0.2
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
    wai-cors-0.2.7-KbupsdQ0ew97grCGJJX2rX
    wai-extra-3.0.28-1ai1gncnCzmJyD6zsOcLM3
    wai-middleware-static-0.8.2-KLbz4LKryKBQzw7EXjojF
haddock-interfaces: /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html: /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> postgrest-6.0.0-55-x86_64.pkg.tar.xz: usr/share/haskell/register/postgrest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgrest
version: 6.0.0
id: postgrest-6.0.0-H5ZgHmqEugdLeEv9P8EnL5
key: postgrest-6.0.0-H5ZgHmqEugdLeEv9P8EnL5
license: MIT
maintainer: Steve Chávez <stevechavezast@gmail.com>
author: Joe Nelson, Adam Baker
homepage: https://postgrest.org
synopsis: REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for the tables and views, supporting all HTTP verbs that security
    permits.
category: Executable, PostgreSQL, Network APIs
abi: 26c7a544b084b093186efd3c2468cef1
exposed: True
exposed-modules:
    PostgREST.ApiRequest PostgREST.App PostgREST.Auth PostgREST.Config
    PostgREST.DbRequestBuilder PostgREST.DbStructure PostgREST.Error
    PostgREST.Middleware PostgREST.OpenAPI PostgREST.Parsers
    PostgREST.QueryBuilder PostgREST.RangeQuery PostgREST.Types
hidden-modules: Paths_postgrest
import-dirs: /usr/lib/ghc-8.6.5/site-local/postgrest-6.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/postgrest-6.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/postgrest-6.0.0
hs-libraries: HSpostgrest-6.0.0-H5ZgHmqEugdLeEv9P8EnL5
depends:
    HTTP-4000.3.14-MD6kNGiUwi1l7RLMbee6g
    Ranged-sets-0.4.0-2PchdoGuiayH3uspliUnwe
    aeson-1.4.6.0-6SSxkzo3COEI5l1mOYJmxL
    ansi-wl-pprint-0.6.9-37GARRLGI1c3EMKKxSVRl0 base-4.12.0.0
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    cassava-0.5.2.0-8Du2Yyr9GN14usDmmst0N0
    configurator-pg-0.1.0.3-7yaDMBEO8dV27xGcIAgKV5 containers-0.6.0.1
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    contravariant-extras-0.3.5-Lfxn0XZQKObJkzvZxANsYm
    cookie-0.4.5-G7Q94cRAamcIKEZucf4yoC
    either-5.0.1.1-2VKwsQfBk468OCmiRorzav
    gitrev-1.3.1-28bODUJmuLsJT3tLybQkQz
    hasql-1.4-7DuaJn63rsUFliuDDAVnBg
    hasql-pool-0.5.1-FEchdQucQndCWeUFDIpeYc
    hasql-transaction-0.7.2-9H9kXCT6yAqB9C4geqVkSv
    heredoc-0.2.0.0-5CGfN4QKKxO6xWz8UL0AnE
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    insert-ordered-containers-0.2.2-8WeNO9SkMCw16i6H55rASs
    interpolatedstring-perl6-1.0.2-7EaGRMXyefqEWcJSOmxCL2
    jose-0.7.0.0-5b06jszIxNhBquMXSOJ4To
    lens-4.17.1-LAhRbmSla4gFq61XVUqFfx
    lens-aeson-1.0.2-HFehUdOhTRF10UbgmeeHaV
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5
    parsec-3.1.13.0 protolude-0.2.4-2qoMYhlKlNqBovj30f65Uv
    regex-tdfa-1.2.3.2-1zrqdepzFAcLwdkKMIY7hi
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    swagger2-2.3.1.1-5moHCLokf6CCfNq5udfweC text-1.2.3.1 time-1.8.0.2
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
    wai-cors-0.2.7-KbupsdQ0ew97grCGJJX2rX
    wai-extra-3.0.28-9vy9sBkFsxZ4EgdKYtbNjQ
    wai-middleware-static-0.8.3-8DqcOa4ir1DH15vzlp99mD
haddock-interfaces: /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html: /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
